==> haskell-hls-code-range-plugin-2.0.0.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-code-range-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-code-range-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-code-range-plugin-2.0.0.0-8Ps7Y2qrkuLCBuq8ATjFBN
key:                  hls-code-range-plugin-2.0.0.0-8Ps7Y2qrkuLCBuq8ATjFBN
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  144e3dfb6714aad26f39db166e9d3360
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-2.0.0.0-8Ps7Y2qrkuLCBuq8ATjFBN
depends:
    aeson-2.1.2.1-3xjz2RyG2JVHhJgBzFxi7A base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-Dogq4JQiVI0JTl9E7yM5k0
    ghcide-2.0.0.0-E5YS0PSvhcVFS9KT5DwHbk
    hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    hls-plugin-api-2.0.0.0-IGiAqukxjS65aDeXxEc0SS
    lens-5.2.3-9tvnz3pLdcPH5JzlkQxTXA
    lsp-1.6.0.0-J5ZrIY2B3yn7lxF8lzfDe0 mtl-2.2.2
    semigroupoids-6.0.0.1-EsDekxjOCgO6Hkl2ZFNy0d text-2.0.2
    transformers-0.5.6.2 vector-0.13.1.0-93FGbMU4lvK4yKJkYGTpJX

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-code-range-plugin-2.0.0.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-code-range-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-code-range-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-code-range-plugin-2.0.0.0-9dEEGZGD5pACSo3YdnCOFT
key:                  hls-code-range-plugin-2.0.0.0-9dEEGZGD5pACSo3YdnCOFT
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  2c691bec19f5dcf7a9c8f58742c8edd7
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-2.0.0.0-9dEEGZGD5pACSo3YdnCOFT
depends:
    aeson-2.1.2.1-25ntyCXNIMdHgIjcbgcdOM base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-9yFW5HMy3QJKMvZBMWGOPz
    ghcide-2.0.0.0-4JwRVBPgvaOHcN553xe4Ur
    hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    hls-plugin-api-2.0.0.0-Ei7P6RE464bGLnm9IUdFJ
    lens-5.2.3-9B9P7XM4qGB6Xd7Di9aRFA
    lsp-1.6.0.0-JssQdMMkdnV6Y1aZJgkn3p mtl-2.2.2
    semigroupoids-6.0.0.1-At7Omlh9GqgC8Sb6O7re5 text-2.0.2
    transformers-0.5.6.2 vector-0.13.1.0-93FGbMU4lvK4yKJkYGTpJX

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
